//Called Basic Skateboard so I don't overwrite the other skateboard Add-On that was made if anyone downloaded it

//we need the jeep add-on for this, so force it to load
%error = ForceRequiredAddOn("Vehicle_Jeep");

if(%error == $Error::AddOn_Disabled)
{
   //A bit of a hack:
   //  we just forced the jeep to load, but the user had it disabled
   //  so lets make it so they can't select it
   JeepVehicle.uiName = "";
}

if(%error == $Error::AddOn_NotFound)
{
   //we don't have the jeep, so we're screwed
   error("ERROR: Vehicle_Basic_Skateboard - required add-on Vehicle_Jeep not found");
}

datablock WheeledVehicleTire(bskateboardTire)
{
   shapeFile = "./skateboardtire.dts";
	
	mass = 10;
    radius = 1;
    staticFriction = 5;
   kineticFriction = 5;
   restitution = 0.5;	

   // Spring that generates lateral tire forces
   lateralForce = 18000;
   lateralDamping = 4000;
   lateralRelaxation = 0.01;

   // Spring that generates longitudinal tire forces
   longitudinalForce = 14000;
   longitudinalDamping = 2000;
   longitudinalRelaxation = 0.01;
};

datablock WheeledVehicleSpring(bskateboardSpring)
{
   // Wheel suspension properties
   length = 0.20;			 // Suspension travel
   force = 3000; //1550;		 // Spring force
   damping = 1000; //1000;		 // Spring damping
   antiSwayForce = 1; //1;		 // Lateral anti-sway force
};

// Vehicle //
/////////////
datablock WheeledVehicleData(bskateboardVehicle)
{
	category = "Vehicles";
	displayName = " ";
	shapeFile = "./skateboard.dts";
	emap = true;
	minMountDist = 3;
   
   numMountPoints = 1;
   mountThread[0] = "root";

	maxDamage = 20.00;
	destroyedLevel = 20.00;
	speedDamageScale = 1.04;
	collDamageThresholdVel = 20.0;
	collDamageMultiplier   = 0.02;

	massCenter = "0 0 0";
   //massBox = "2 5 1";

	maxSteeringAngle = 0.25;  // Maximum steering angle, should match animation
	integration = 2;           // Force integration time: TickSec/Rate


	// 3rd person camera settings
	cameraRoll = false;         // Roll the camera with the vehicle
	cameraMaxDist = 4;         // Far distance from vehicle
	cameraOffset = 3.0;        // Vertical offset from camera mount point
	cameraLag = 0.0;           // Velocity lag of camera
	cameraDecay = 0.75;        // Decay per sec. rate of velocity lag
	cameraTilt = 0.4;
   collisionTol = 0.1;        // Collision distance tolerance
   contactTol = 0.1;

	useEyePoint = True;	

	defaultTire	= bskateboardTire;
	defaultSpring	= bskateboardSpring;
	//flatTire	= JeepFlatTire;
	//flatSpring	= JeepFlatSpring;

   numWheels = 4;

	// Rigid Body
	mass = 300;
	density = 5.0;
	drag = 3.0;
	bodyFriction = 0.6;
	bodyRestitution = 0.6;
	minImpactSpeed = 10;        // Impacts over this invoke the script callback
	softImpactSpeed = 10;       // Play SoftImpact Sound
	hardImpactSpeed = 15;      // Play HardImpact Sound
	groundImpactMinSpeed    = 10.0;

	// Engine
	engineTorque = 8000; //4000;       // Engine power
	engineBrake = 1000;         // Braking when throttle is 0
	brakeTorque = 1000;        // When brakes are applied
	maxWheelSpeed = 25;        // Engine scale by current speed / max speed

	rollForce		= 500;
	yawForce		= 3000;
	pitchForce		= 500;
	rotationalDrag		= 0.05;

   // Advanced Steering
   steeringAutoReturn = true;
   steeringAutoReturnRate = 3.0;
   steeringAutoReturnMaxSpeed = 10;
   steeringUseStrafeSteering = false;
   steeringStrafeSteeringRate = 0.1;

	// Energy
	maxEnergy = 100;
	jetForce = 3000;
	minJetEnergy = 30;
	jetEnergyDrain = 2;
		

	
	// Sounds
	softImpactSound = slowImpactSound;
	hardImpactSound = fastImpactSound;
	//wheelImpactSound = slowImpactSound;

	//   explosion = VehicleExplosion;
	justcollided = 0;

   uiName = "Basic Skateboard ";
	rideable = true;
		lookUpLimit = 0.65;
		lookDownLimit = 0.45;

	paintable = true;
   
   damageEmitter[0] = VehicleBurnEmitter;
	damageEmitterOffset[0] = "0.0 0.0 0.0 ";
	damageLevelTolerance[0] = 0.99;

   damageEmitter[1] = VehicleBurnEmitter;
	damageEmitterOffset[1] = "0.0 0.0 0.0 ";
	damageLevelTolerance[1] = 1.0;

   numDmgEmitterAreas = 1;

   initialExplosionProjectile = bskateboardExplosionProjectile;
   initialExplosionOffset = 0;         //offset only uses a z value for now

   burnTime = 4000;

   finalExplosionProjectile = bskateboardFinalExplosionProjectile;
   finalExplosionOffset = 0.5;          //offset only uses a z value for now

   minRunOverSpeed    = 4;   //how fast you need to be going to run someone over (do damage)
   runOverDamageScale = 8;   //when you run over someone, speed * runoverdamagescale = damage amt
   runOverPushScale   = 1.2; //how hard a person you're running over gets pushed
};

function bskateboardvehicle::onAdd(%this,%obj)
{
	parent::onadd(%this,%obj);
	%obj.mountable = true;

	%obj.setWheelSteering(0,1);
	%obj.setWheelSteering(1,1);
	%obj.setWheelSteering(2,-1);
	%obj.setWheelSteering(3,-1);

	%obj.setWheelTire(0, bskateboardTire);
	%obj.setWheelTire(1, bskateboardTire);
	%obj.setWheelTire(2, bskateboardTire);
	%obj.setWheelTire(3, bskateboardTire);

	%obj.playThread(0,"Action");
}

function bskateboardVehicle::OnTrigger(%data,%obj,%slot,%trig)
{
	if(%slot == 2)
	{
		%data.ollie(%obj,%trig);
	}
}

function bskateboardVehicle::ollie(%this,%obj,%o)
{
	if(%o)
	{
		%obj.chargeOllieTime = $Sim::Time;
	} else {
		%time = mClampF(($Sim::Time - %obj.chargeOllieTime) * 12,4,8);
		%obj.chargeOllieTime = "";
		%up = %obj.getUpVector();
		%down = vectorScale(%up,-1);
		%pos = %obj.getWorldBoxCenter();
		%end = vectorAdd(%pos,%down);

		// Checking beneath it to jump off stuff btw
		%mask = $TypeMasks::fxBrickObjectType | $TypeMasks::TerrainObjectType | $TypeMasks::InteriorObjectType;
		%col = containerRayCast(%pos,%end,%mask);
		if(isObject(%col))
		{
			%vel = %obj.getVelocity();
			%newvel = vectorAdd(%vel,vectorScale(%up,2));
			%newvel = vectorAdd(%newvel,vectorScale("0 0 1",%time));
			%obj.setVelocity(%newvel);
		}
	}
}